#!/usr/bin/perl -w
# Copyright, Field Precision
# Generation of image data for Mesh from a formula
#
#                      IMAGE DATA FILE FORMAT
#
# Structure of the table and file format
#  I is the column index (x direction)
#  J is the row index (y direction)
#  K is the depth index (z direction)
#
#            ___________________________________
# YMax  JMax|                                   |
#           |                                   |
#           |                                   |
#           |                                   |
#           |                                   |
#          J|                                   |
#           |                                   |
#           |                                   |
#           |                                   |
#           |                                   |
#           |                                   |
# YMin     0|___________________________________|
#           0                 I                IMax
#         XMin                                 XMax
#
# File format
# Same format as HiPhi and MagNum matrix files
#
# IMax, JMax
# XMin, YMin, XMax, YMax
# H(0,0)
# H(1,0)
# H(2,0)
#   ...
# H(IMax,0)
# H(0,1)
#   ...  
# H(I,J)
#   ...
# H(IMax,JMax)
#
# Number of data lines: (IMax+1)*(JMax+1)
# Values are tabulated at spatial intervals 
#    Dx = (XMax-XMin)/IMax
#    Dy = (YMax-YMin)/JMax
#
# ==========================================================
# Enter control parameters
# X axis
$XMin = -3.0;
$XMax = 3.0;
$IMax = 100;
# Y axis
$YMin = -3.0;
$YMax =  3.0;
$JMax = 100;
# File name
$FileName = ">" . "FUNCTION01.DAT";
$Title = "* " . "DataFileExample01\n";
# ==========================================================

# Open a file and print the header
open (OutData, $FileName);
print OutData $Title;
printf OutData (" %6d %6d \n",$IMax,$JMax);
printf OutData (" %12.4E %12.4E %12.4E %12.4E \n",$XMin,$YMin,$XMax,$YMax);

# Setup and main loop
$Dx = ($XMax-$XMin)/$IMax;
$Dy = ($YMax-$YMin)/$JMax;
for ($J=0; $J < ($JMax+1); $J++) {
  $Y = $YMin + $Dy*$J;
  for ($I=0; $I < ($IMax+1); $I++) {
    $X = $XMin + $Dx*$I;
    $H = HValue($X,$Y);
    printf OutData ("%12.4E\n", $H);
  };
};

# Wrap up
close (OutData);

# ==========================================================
# Enter function to calculate z values
# =================================================
  sub HValue {
    my ($x,$y) = @_;
    my ($f);
    $r = ($x**2+$y**2);
    if ($r == 0.0) {
      $f = 1.0; }
    else {
      $f = ($x**2*$y+$x**2-$y**2)/$r;}
    return $f;
    }

# ==========================================================
